@@ -16,3 +16,8 @@ class EndOfFileError(Exception):
 
 class UnsupportedAttributeError(Exception):
     pass
+
+
+def type_error_message(value, include_hint=True):
+    return f"Expected int, found: {value.__class__}. " + (f"Maybe you meant: '{value}.ID'?" if include_hint else "")
+
