@@ -7,10 +7,11 @@ from typing import List, Dict
 from AoE2ScenarioParser.datasets.effects import EffectId
 from AoE2ScenarioParser.datasets.players import PlayerId
 from AoE2ScenarioParser.helper import helper
+from AoE2ScenarioParser.helper.list_functions import hash_list, list_changed, update_order_array
 from AoE2ScenarioParser.objects.aoe2_object import AoE2Object
 from AoE2ScenarioParser.objects.data_objects.trigger import Trigger
 from AoE2ScenarioParser.objects.support.enums.group_by import GroupBy
-from AoE2ScenarioParser.objects.support.trigger_select import TriggerSelect
+from AoE2ScenarioParser.objects.support.trigger_select import TriggerSelect, TS
 from AoE2ScenarioParser.sections.retrievers.retriever_object_link import RetrieverObjectLink
 
 
@@ -27,7 +28,7 @@ class TriggerManager(AoE2Object):
                  trigger_display_order: List[int],
                  ):
 
-        self._trigger_hash = helper.hash_list(triggers)
+        self._trigger_hash = hash_list(triggers)
         self.triggers: List[Trigger] = triggers
         self.trigger_display_order: List[int] = trigger_display_order
 
@@ -39,15 +40,15 @@ class TriggerManager(AoE2Object):
 
     @triggers.setter
     def triggers(self, value):
-        self._trigger_hash = helper.hash_list(value)
+        self._trigger_hash = hash_list(value)
         self._triggers = value
         self.trigger_display_order = list(range(len(value)))
 
     @property
     def trigger_display_order(self):
-        if helper.list_changed(self.triggers, self._trigger_hash):
-            helper.update_order_array(self._trigger_display_order, len(self.triggers))
-            self._trigger_hash = helper.hash_list(self.triggers)
+        if list_changed(self.triggers, self._trigger_hash):
+            update_order_array(self._trigger_display_order, len(self.triggers))
+            self._trigger_hash = hash_list(self.triggers)
         return self._trigger_display_order
 
     @trigger_display_order.setter
@@ -69,7 +70,7 @@ class TriggerManager(AoE2Object):
         Args:
             from_player (IntEnum): The central player this trigger is created for. This is the player that will not get
                 a copy.
-            trigger_select (AoE2ScenarioParser.objects.support.trigger_select.TriggerSelect): An object used to identify which trigger to select.
+            trigger_select (TriggerSelect): An object used to identify which trigger to select.
             change_from_player_only (bool): If set to True, only change player attributes in effects and conditions that
                 are equal to the player defined using the `from_player` parameter.
             include_player_source (bool): If set to True, allow player source attributes to be changed while copying.
@@ -78,7 +79,7 @@ class TriggerManager(AoE2Object):
             include_player_target (bool): If set to True, allow player target attributes to be changed while copying.
                 Player target attributes are attributes where a player is defined as the target such as change ownership
                 or sending resources. If set to False these attributes will remain unchanged.
-            trigger_ce_lock (AoE2ScenarioParser.objects.support.trigger_ce_lock.TriggerCELock): The TriggerCELock object. Used to lock certain (types) of conditions or
+            trigger_ce_lock (TriggerCELock): The TriggerCELock object. Used to lock certain (types) of conditions or
                 effects from being changed while copying.
             include_gaia (bool): If True, GAIA is included in the copied list. (Also when `create_copy_for_players` is
                 defined)
@@ -157,7 +158,7 @@ class TriggerManager(AoE2Object):
         Creates an exact copy (deepcopy) of this trigger.
 
         Args:
-            trigger_select (AoE2ScenarioParser.objects.support.trigger_select.TriggerSelect): An object used to identify which trigger to select.
+            trigger_select (TriggerSelect): An object used to identify which trigger to select.
 
         Returns:
             The newly copied trigger
@@ -188,7 +189,7 @@ class TriggerManager(AoE2Object):
         Args:
             from_player (IntEnum): The central player this trigger is created for. This is the player that will not get
                 a copy.
-            trigger_select (AoE2ScenarioParser.objects.support.trigger_select.TriggerSelect): An object used to identify which trigger to select.
+            trigger_select (TriggerSelect): An object used to identify which trigger to select.
             change_from_player_only (bool): If set to True, only change player attributes in effects and conditions that
                 are equal to the player defined using the `from_player` parameter.
             include_player_source (bool): If set to True, allow player source attributes to be changed while copying.
@@ -197,13 +198,13 @@ class TriggerManager(AoE2Object):
             include_player_target (bool): If set to True, allow player target attributes to be changed while copying.
                 Player target attributes are attributes where a player is defined as the target such as change ownership
                 or sending resources. If set to False these attributes will remain unchanged.
-            trigger_ce_lock (AoE2ScenarioParser.objects.support.trigger_ce_lock.TriggerCELock): The TriggerCELock object. Used to lock certain (types) of conditions or
+            trigger_ce_lock (TriggerCELock): The TriggerCELock object. Used to lock certain (types) of conditions or
                 effects from being changed while copying.
             include_gaia (bool): If True, GAIA is included in the copied list. (Also when `create_copy_for_players` is
                 defined)
             create_copy_for_players (List[IntEnum]): A list of Players to create a copy for. The `from_player` will be
                 excluded from this list.
-            group_triggers_by (AoE2ScenarioParser.objects.support.enums.group_by.GroupBy): How to group the newly added triggers.
+            group_triggers_by (GroupBy): How to group the newly added triggers.
 
         Returns:
             The newly created triggers in a dict using the Player as key and as value with a list of triggers
@@ -320,7 +321,7 @@ class TriggerManager(AoE2Object):
             include_player_target (bool): If set to True, allow player target attributes to be changed while replacing.
                 Player target attributes are attributes where a player is defined as the target such as change ownership
                 or sending resources. If set to False these attributes will remain unchanged.
-            trigger_ce_lock (AoE2ScenarioParser.objects.support.trigger_ce_lock.TriggerCELock): The TriggerCELock object. Used to lock certain (types) of conditions or
+            trigger_ce_lock (TriggerCELock): The TriggerCELock object. Used to lock certain (types) of conditions or
                 effects from being changed.
 
         Returns:
@@ -390,7 +391,6 @@ class TriggerManager(AoE2Object):
                 trigger_attr[key] = locals()[key]
         new_trigger = Trigger(name=name, trigger_id=len(self.triggers), **trigger_attr)
         self.triggers.append(new_trigger)
-        # helper.update_order_array(self._trigger_display_order, len(self.triggers))
         return new_trigger
 
     def get_trigger(self, trigger_select: TriggerSelect) -> Trigger:
@@ -411,7 +411,6 @@ class TriggerManager(AoE2Object):
 
     def _find_trigger_tree_nodes_recursively(self, trigger, known_node_indexes: List[int]) -> None:
         found_node_indexes = TriggerManager._find_trigger_tree_nodes(trigger)
-        # unknown_node_indexes = found_node_indexes.difference(known_node_indexes)
         unknown_node_indexes = [i for i in found_node_indexes if i not in known_node_indexes]
 
         if len(unknown_node_indexes) == 0:
@@ -422,7 +421,7 @@ class TriggerManager(AoE2Object):
         for index in unknown_node_indexes:
             self._find_trigger_tree_nodes_recursively(self.triggers[index], known_node_indexes)
 
-    def _validate_and_retrieve_trigger_info(self, trigger_select) -> (int, int, TriggerManager):
+    def _validate_and_retrieve_trigger_info(self, trigger_select) -> (int, int, Trigger):
         trigger = trigger_select.trigger
         trigger_index = trigger_select.trigger_index
         display_index = trigger_select.display_index
